==> xorg-edit_06.08.02_src.tar.gz: xorg-edit/sources/device.h <==
#ifndef DEVICE_H
#define DEVICE_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionList.h"

// **************************
// Class Definition
// **************************

class device
{
public:
  device(void);   // constructor
  ~device(void);   // destructor
  device(const device &dev); // copy constructor

  device operator=(const device &dev); // copy constructor

  void AddComment(const wxString& com);  // set comment
  void SetId(const wxString& id, const wxString& com=wxEmptyString);      // set identifier
  void SetDriver(const wxString& dr, const wxString& com=wxEmptyString);  // set driver
  void SetBus(const wxString& bus, const wxString& com=wxEmptyString);    // set bus type
  void SetScreen(const wxString& scre, const wxString& com=wxEmptyString);    // set screen to use
  void SetVideoRam(const wxString& ram, const wxString& com=wxEmptyString);     // set video ram size

  const wxString& GetId(void) const;           // return identifier
  const wxString& GetDriver(void) const;       // retun driver name
  const wxString& GetBus(void) const;          // return bus
  const wxString& GetScreen(void) const;       // return used screen
  const wxString& GetVideoRam(void) const;     // return video ram size

  const wxArrayString& GetComment(void) const;          // return comment
  const wxString& GetIdComment(void) const;           // return identifier comment
  const wxString& GetDriverComment(void) const;       // retun driver name comment
  const wxString& GetBusComment(void) const;          // return bus comment
  const wxString& GetScreenComment(void) const;       // return used screen comment
  const wxString& GetVideoRamComment(void) const;     // return video ram size comment

  void RemoveOption(const unsigned int index);    // remove option
  void AddOption(const option &opt);              // add option
  void SetOption(const unsigned int index, const option &opt); // set option

  option& GetOptionE(const unsigned int index);                // get option
  const option& GetOption(const unsigned int index) const;     // get option
  unsigned int GetOptionSize(void) const;                      // return size of options

  void Clear(void);          // clear everything

private:
  wxString identifier;      // card identifier
  wxString driver;          // driver name
  wxString busID;           // bus type
  wxString screen;          // which screen is used
  wxString videoRam;        // video ram option

  // Note: Any additional settings will not be recognized like:
  // Chipset, Ramdac, DacSpeed, Clocks, ClockChip,
  // BiosBase, MemBase, IOBase, ChipID, ChipRev, TextClockFreq

  wxArrayString comment;                // comment for whole block
  wxString identifierComment;
  wxString driverComment;
  wxString busIDComment;
  wxString screenComment;
  wxString videoRamComment;
  optionList options;       // all options
};

#endif // DEVICE_H

==> xorg-edit_06.10.08_src.tar.gz: xorg-edit/sources/device.h <==
#ifndef DEVICE_H
#define DEVICE_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionlist.h"

// **************************
// Class Definition
// **************************

class Device
{
public:
  Device(void);   // constructor
  ~Device(void);   // destructor
  Device(const Device &dev); // copy constructor

  Device& operator=(const Device &dev); // copy constructor

  void AddComment(const wxString& com);  // set comment
  void SetId(const wxString& id, const wxString& com=wxEmptyString);      // set identifier
  void SetDriver(const wxString& dr, const wxString& com=wxEmptyString);  // set driver
  void SetBus(const wxString& bus, const wxString& com=wxEmptyString);    // set bus type
  void SetScreen(const wxString& scre, const wxString& com=wxEmptyString);    // set screen to use
  void SetVideoRam(const wxString& ram, const wxString& com=wxEmptyString);     // set video ram size

  const wxString& GetId(void) const;           // return identifier
  const wxString& GetDriver(void) const;       // retun driver name
  const wxString& GetBus(void) const;          // return bus
  const wxString& GetScreen(void) const;       // return used screen
  const wxString& GetVideoRam(void) const;     // return video ram size

  const wxArrayString& GetComment(void) const;          // return comment
  const wxString& GetIdComment(void) const;           // return identifier comment
  const wxString& GetDriverComment(void) const;       // retun driver name comment
  const wxString& GetBusComment(void) const;          // return bus comment
  const wxString& GetScreenComment(void) const;       // return used screen comment
  const wxString& GetVideoRamComment(void) const;     // return video ram size comment

  void RemoveOption(const int index);    // remove option
  void AddOption(const Option &opt);              // add option
  void SetOption(const int index, const Option &opt); // set option

  Option& GetOption(const int index);                 // get option
  const Option& GetOption(const int index) const;     // get option
  const int GetOptionSize(void) const;                      // return size of options

  void Clear(void);          // clear everything

private:
  wxString identifier;      // card identifier
  wxString driver;          // driver name
  wxString busID;           // bus type
  wxString screen;          // which screen is used
  wxString videoRam;        // video ram option

  // Note: Any additional settings will not be recognized like:
  // Chipset, Ramdac, DacSpeed, Clocks, ClockChip,
  // BiosBase, MemBase, IOBase, ChipID, ChipRev, TextClockFreq

  wxArrayString comment;                // comment for whole block
  wxString identifierComment;
  wxString driverComment;
  wxString busIDComment;
  wxString screenComment;
  wxString videoRamComment;
  OptionList options;       // all options
};

#endif // DEVICE_H
